@@ -9,9 +9,6 @@ pub struct Context {
 fn main() {
     let env = Environment::new();
     let expr = env.compile_expression("foo == 42").unwrap();
-    let result = expr.eval(&Context {
-        foo: 42
-    }).unwrap();
+    let result = expr.eval(&Context { foo: 42 }).unwrap();
     println!("result: {:?}", result);
 }
-
